@@ -1,6 +1,7 @@
 from braintree.address_gateway import AddressGateway
 from braintree.credit_card_gateway import CreditCardGateway
 from braintree.customer_gateway import CustomerGateway
+from braintree.settlement_batch_summary_gateway import SettlementBatchSummaryGateway
 from braintree.subscription_gateway import SubscriptionGateway
 from braintree.transaction_gateway import TransactionGateway
 from braintree.transparent_redirect_gateway import TransparentRedirectGateway
@@ -11,6 +12,7 @@ class BraintreeGateway(object):
         self.address = AddressGateway(self)
         self.credit_card = CreditCardGateway(self)
         self.customer = CustomerGateway(self)
+        self.settlement_batch_summary = SettlementBatchSummaryGateway(self)
         self.subscription = SubscriptionGateway(self)
         self.transaction = TransactionGateway(self)
         self.transparent_redirect = TransparentRedirectGateway(self)
